bayespy.inference.vmp.nodes.multinomial.MultinomialMoments.compute_fixed_moments
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialMoments.compute_fixed_moments